@@ -10,7 +10,6 @@ IPTABLES=iptables
 aembit_agent_proxy_user_name=aembit_agent_proxy
 aembit_group_id=$(id --group "${aembit_agent_proxy_user_name}")
 agent_proxy_port=38080
-agent_dns_port=8053
 container_cidr=$AEMBIT_DOCKER_CONTAINER_CIDR
 # https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16
 azure_platform_resources_ip="168.63.129.16"
@@ -56,11 +55,6 @@ unlink_and_delete_aembit_chains() {
 
     remove_ipv4_rule filter INPUT -j "${aembit_filter_INPUT}"
     remove_ipv4_chain filter "${aembit_filter_INPUT}"
-
-    if firewalld_is_active_and_running; then
-        # Remove firewalld specific special rich rule for accepting untracked dns responses
-        fwd_remove_rich_rule source-port port=53 protocol=udp accept
-    fi
 }
 
 # check if firewalld is active and running
@@ -216,84 +210,6 @@ function save_and_reload_daemon() {
     fi
 }
 
-function dns_proxy_rules() {
-    # We encountered a bug where egress traffic from the Agent Proxy's DNS proxy will
-    # be routed back to itself. This rule prevents this bug.
-    # This was happening for the following reasons:
-    #
-    # 1. The Client Workload and the Agent Proxy operate on shared networking infrastructure.
-    #    This means that they have the same IP address.
-    # 2. When the Client Workload initially connects, the DNS NAT rule in this file would
-    #    overwrite the destination IP and port to point at the Agent Proxy.
-    # 3. After an iptables rule is evaluated, it is saved as a "connection" by conntrack.
-    #    It is not evaluated again, unless the connection in conntrack expires.
-    #    This means that the connection is saved in conntrack as:
-    #        - Original direction: <CW/AP IP>:<EPHEMERAL PORT X> -> <EXTERNAL DNS IP>:53
-    #        - Reply direction: 127.0.0.1:8053 -> <CW/AP IP>:<EPHEMERAL PORT X>
-    # 4. Since the Agent Proxy requests an ephemeral port on the host to handle the
-    #    outgoing DNS request, sometimes it is assigned a port that was previously
-    #    used and released by the Client Workload. However, since the NAT rule was already
-    #    evaluated, the mapping from step #3 was already saved, meaning that the outbound
-    #    DNS is sent to the Agent Proxy, forming a loop.
-    #
-    # To avoid this loop, in this line we set the NOTRACK target on outgoing DNS packets on
-    # the "raw" table, which is evaluated prior to conntrack. This causes conntrack to not
-    # try to associate the packet with any connection, even if one already exists.
-    #
-    # See https://www.frozentux.net/iptables-tutorial/iptables-tutorial.html#STATEMACHINE
-    # for more information on conntrack.
-    add_ipv4_rule raw "${aembit_raw_OUTPUT}" -p udp --dport 53 -m owner --gid-owner "${aembit_group_id}" -j CT --notrack
-
-    # The story for this rule is extremely similar to the above (only occurring in the VM environment).
-    #
-    # 1. CW used an ephemeral port to communicate with ResolveD (running on 127.0.0.53:53), and it's added to conntrack
-    # 2. CW releases this port, and it becomes immediately available
-    # 3. AP was accidentally given this port by the system when it tried to do DNS resolution as part of connecting to
-    # a server workload.
-    # 4. AP request to 127.0.0.53:53 is NOTRACK (per the rule above)
-    # 5. ResolveD (127.0.0.53:53) response to AP hits a match in conntrack and NAT (for some reason, decides to modify
-    # resolved port), and this packet is unreachable.
-    #
-    # As a result, we are adding this rule to make sure that traffic from ResolveD is not NATed.
-    # TODO: move it along with systemd-resolved rule few lines below.
-    add_ipv4_rule raw "${aembit_raw_OUTPUT}" -p udp -s 127.0.0.53 --sport 53 -j CT --notrack
-
-    # Added due to a bug in RHEL-8.6 which causes these packets to be source NAT'ed as soon as any NAT rule is confiured.
-    add_ipv4_rule raw "${aembit_raw_PREROUTING}" -p udp --sport 53 -j CT --notrack
-
-    # firewalld by default disallows packets for a connection that is untracked in its filter INPUT chain.
-    # Trace log for such rejects (see the last rule in filter_INPUT chain below) -
-    #   "trace id c124d79a inet firewalld filter_INPUT rule reject with icmpx type admin-prohibited (verdict drop)"
-    # Snippet of the default filter_INPUT rules.
-    # chain filter_INPUT {
-    #                type filter hook input priority filter + 10; policy accept;
-    #                ct state { established, related } accept
-    #                ct status dnat accept
-    #                iifname "lo" accept
-    #                jump filter_INPUT_POLICIES_pre
-    #                jump filter_INPUT_ZONES_SOURCE
-    #                jump filter_INPUT_ZONES
-    #                jump filter_INPUT_POLICIES_post
-    #                ct state { invalid } drop
-    #                reject with icmpx type admin-prohibited
-    # }
-    # This would add the rule to `filter_IN_public_allow` chain which is called from filter_INPUT through filter_INPUT_ZONES
-    # iptables equivalent rule would be `iptables -t filter -A INPUT -p udp --sport 53 -m conntrack --ctstate UNTRACKED -j ACCEPT`
-    if firewalld_is_active_and_running; then
-        fwd_add_rich_rule source-port port=53 protocol=udp accept
-    fi
-
-    # Ignore outbound traffic from systemd-resolved.
-    # TODO: In case systemd-resolved received DNS request via DBus-API, this request should not be ignored.
-    resolve_d_user_id=$(id --user systemd-resolve);
-    if [ -n "${resolve_d_user_id}" ]; then
-        add_ipv4_rule nat "${aembit_nat_OUTPUT}" -p udp --dport 53 -m owner --uid-owner "${resolve_d_user_id}" -j RETURN
-    fi
-
-    # REDIRECT DNS to Agent Proxy's DNS port.
-    add_ipv4_rule nat "${aembit_nat_OUTPUT}" -p udp --dport 53 -j REDIRECT --to "${agent_dns_port}"
-}
-
 # Filter rules to allow TCP traffic to the AP.
 function allow_tcp_traffic_to_ap() {
     # Allow local traffic to be sent to the Agent Proxy traffic port over loopback.
@@ -353,7 +269,7 @@ function tcp_proxy_rules() {
     # Redirect outbound TCP traffic to AP.
     redirect_outbound_tcp_traffic_to_ap
 
-    # Redirect pre-routing TCP traffic from local containers.
+    # Redirect pre-routing TCP from local containers.
     if [ -n "$container_cidr" ]; then
         redirect_container_traffic_to_ap
     fi
@@ -365,8 +281,6 @@ function tcp_proxy_rules() {
 function install_traffic_steering_rules_to_ap() {
     create_all_aembit_chains
 
-    dns_proxy_rules
-
     tcp_proxy_rules
 
     link_all_aembit_chains
@@ -395,4 +309,3 @@ case "${OPTION}" in
         echo "Invalid option - ${OPTION}"
         ;;
 esac
-
